# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapdata.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rmapdata.proto\x12\x07karcher\"[\n\nMapExtInfo\x12\x15\n\rtaskBeginDate\x18\x01 \x01(\x05\x12\x15\n\rmapUploadDate\x18\x02 \x01(\x05\x12\x10\n\x08mapValid\x18\x03 \x01(\x05\x12\r\n\x05\x61ngle\x18\x04 \x01(\x02\"\x8a\x01\n\x0bMapHeadInfo\x12\x11\n\tmapHeadId\x18\x01 \x01(\x05\x12\r\n\x05sizeX\x18\x02 \x01(\x05\x12\r\n\x05sizeY\x18\x03 \x01(\x05\x12\x0c\n\x04minX\x18\x04 \x01(\x02\x12\x0c\n\x04minY\x18\x05 \x01(\x02\x12\x0c\n\x04maxX\x18\x06 \x01(\x02\x12\x0c\n\x04maxY\x18\x07 \x01(\x02\x12\x12\n\nresolution\x18\x08 \x01(\x02\"\x1e\n\x0bMapDataInfo\x12\x0f\n\x07mapData\x18\x01 \x01(\x0c\"0\n\nAllMapInfo\x12\x11\n\tmapHeadId\x18\x01 \x01(\x05\x12\x0f\n\x07mapName\x18\x02 \x01(\t\"@\n\x18\x44\x65viceCoverPointDataInfo\x12\x0e\n\x06update\x18\x01 \x01(\x05\x12\t\n\x01x\x18\x02 \x01(\x02\x12\t\n\x01y\x18\x03 \x01(\x02\"Z\n\x15\x44\x65viceHistoryPoseInfo\x12\x0e\n\x06poseId\x18\x01 \x01(\x05\x12\x31\n\x06points\x18\x02 \x03(\x0b\x32!.karcher.DeviceCoverPointDataInfo\"7\n\x12\x44\x65vicePoseDataInfo\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\x0b\n\x03phi\x18\x03 \x01(\x02\"Z\n\x15\x44\x65viceCurrentPoseInfo\x12\x0e\n\x06poseId\x18\x01 \x01(\x05\x12\x0e\n\x06update\x18\x02 \x01(\x05\x12\t\n\x01x\x18\x03 \x01(\x02\x12\t\n\x01y\x18\x04 \x01(\x02\x12\x0b\n\x03phi\x18\x05 \x01(\x02\"\'\n\x0f\x44\x65vicePointInfo\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\"o\n\x12\x44\x65viceAreaDataInfo\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0c\n\x04type\x18\x02 \x01(\x05\x12\x11\n\tareaIndex\x18\x03 \x01(\x05\x12(\n\x06points\x18\x04 \x03(\x0b\x32\x18.karcher.DevicePointInfo\"v\n\x1d\x44\x65viceNavigationPointDataInfo\x12\x0f\n\x07pointId\x18\x01 \x01(\x05\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x11\n\tpointType\x18\x03 \x01(\x05\x12\t\n\x01x\x18\x04 \x01(\x02\x12\t\n\x01y\x18\x05 \x01(\x02\x12\x0b\n\x03phi\x18\x06 \x01(\x02\"g\n\x17\x43leanPerferenceDataInfo\x12\x11\n\tcleanMode\x18\x01 \x01(\x05\x12\x12\n\nwaterLevel\x18\x02 \x01(\x05\x12\x11\n\twindPower\x18\x03 \x01(\x05\x12\x12\n\ntwiceClean\x18\x04 \x01(\x05\"\x8f\x02\n\x0cRoomDataInfo\x12\x0e\n\x06roomId\x18\x01 \x01(\x05\x12\x10\n\x08roomName\x18\x02 \x01(\t\x12\x12\n\nroomTypeId\x18\x03 \x01(\x05\x12\x12\n\nmeterialId\x18\x04 \x01(\x05\x12\x12\n\ncleanState\x18\x05 \x01(\x05\x12\x11\n\troomClean\x18\x06 \x01(\x05\x12\x16\n\x0eroomCleanIndex\x18\x07 \x01(\x05\x12.\n\x0croomNamePost\x18\x08 \x01(\x0b\x32\x18.karcher.DevicePointInfo\x12\x35\n\x0b\x63leanPerfer\x18\t \x01(\x0b\x32 .karcher.CleanPerferenceDataInfo\x12\x0f\n\x07\x63olorId\x18\n \x01(\x05\"\"\n\x10\x44\x65viceRoomMatrix\x12\x0e\n\x06matrix\x18\x01 \x01(\x0c\"?\n\x18\x44\x65viceChainPointDataInfo\x12\t\n\x01x\x18\x01 \x01(\x05\x12\t\n\x01y\x18\x02 \x01(\x05\x12\r\n\x05value\x18\x03 \x01(\x05\"\\\n\x17\x44\x65viceRoomChainDataInfo\x12\x0e\n\x06roomId\x18\x01 \x01(\x05\x12\x31\n\x06points\x18\x02 \x03(\x0b\x32!.karcher.DeviceChainPointDataInfo\"\x80\x01\n\x0eObjectDataInfo\x12\x10\n\x08objectId\x18\x01 \x01(\x05\x12\x14\n\x0cobjectTypeId\x18\x02 \x01(\x05\x12\x12\n\nobjectName\x18\x03 \x01(\t\x12\x0f\n\x07\x63onfirm\x18\x04 \x01(\x05\x12\t\n\x01x\x18\x05 \x01(\x02\x12\t\n\x01y\x18\x06 \x01(\x02\x12\x0b\n\x03url\x18\x07 \x01(\t\"f\n\x11\x46urnitureDataInfo\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0e\n\x06typeId\x18\x02 \x01(\x05\x12(\n\x06points\x18\x03 \x03(\x0b\x32\x18.karcher.DevicePointInfo\x12\x0b\n\x03url\x18\x04 \x01(\t\"q\n\tHouseInfo\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x63urMapCount\x18\x03 \x01(\x05\x12\x12\n\nmaxMapSize\x18\x04 \x01(\x05\x12!\n\x04maps\x18\x05 \x03(\x0b\x32\x13.karcher.AllMapInfo\"\x91\x06\n\x08RobotMap\x12\x0f\n\x07mapType\x18\x01 \x01(\x05\x12\'\n\nmapExtInfo\x18\x02 \x01(\x0b\x32\x13.karcher.MapExtInfo\x12%\n\x07mapHead\x18\x03 \x01(\x0b\x32\x14.karcher.MapHeadInfo\x12%\n\x07mapData\x18\x04 \x01(\x0b\x32\x14.karcher.MapDataInfo\x12$\n\x07mapInfo\x18\x05 \x03(\x0b\x32\x13.karcher.AllMapInfo\x12\x33\n\x0bhistoryPose\x18\x06 \x01(\x0b\x32\x1e.karcher.DeviceHistoryPoseInfo\x12\x32\n\rchargeStation\x18\x07 \x01(\x0b\x32\x1b.karcher.DevicePoseDataInfo\x12\x33\n\x0b\x63urrentPose\x18\x08 \x01(\x0b\x32\x1e.karcher.DeviceCurrentPoseInfo\x12\x31\n\x0cvirtualWalls\x18\t \x03(\x0b\x32\x1b.karcher.DeviceAreaDataInfo\x12.\n\tareasInfo\x18\n \x03(\x0b\x32\x1b.karcher.DeviceAreaDataInfo\x12@\n\x10navigationPoints\x18\x0b \x03(\x0b\x32&.karcher.DeviceNavigationPointDataInfo\x12+\n\x0croomDataInfo\x18\x0c \x03(\x0b\x32\x15.karcher.RoomDataInfo\x12-\n\nroomMatrix\x18\r \x01(\x0b\x32\x19.karcher.DeviceRoomMatrix\x12\x33\n\troomChain\x18\x0e \x03(\x0b\x32 .karcher.DeviceRoomChainDataInfo\x12(\n\x07objects\x18\x0f \x03(\x0b\x32\x17.karcher.ObjectDataInfo\x12\x31\n\rfurnitureInfo\x18\x10 \x03(\x0b\x32\x1a.karcher.FurnitureDataInfo\x12&\n\nhouseInfos\x18\x11 \x03(\x0b\x32\x12.karcher.HouseInfob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mapdata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_MAPEXTINFO']._serialized_start=26
  _globals['_MAPEXTINFO']._serialized_end=117
  _globals['_MAPHEADINFO']._serialized_start=120
  _globals['_MAPHEADINFO']._serialized_end=258
  _globals['_MAPDATAINFO']._serialized_start=260
  _globals['_MAPDATAINFO']._serialized_end=290
  _globals['_ALLMAPINFO']._serialized_start=292
  _globals['_ALLMAPINFO']._serialized_end=340
  _globals['_DEVICECOVERPOINTDATAINFO']._serialized_start=342
  _globals['_DEVICECOVERPOINTDATAINFO']._serialized_end=406
  _globals['_DEVICEHISTORYPOSEINFO']._serialized_start=408
  _globals['_DEVICEHISTORYPOSEINFO']._serialized_end=498
  _globals['_DEVICEPOSEDATAINFO']._serialized_start=500
  _globals['_DEVICEPOSEDATAINFO']._serialized_end=555
  _globals['_DEVICECURRENTPOSEINFO']._serialized_start=557
  _globals['_DEVICECURRENTPOSEINFO']._serialized_end=647
  _globals['_DEVICEPOINTINFO']._serialized_start=649
  _globals['_DEVICEPOINTINFO']._serialized_end=688
  _globals['_DEVICEAREADATAINFO']._serialized_start=690
  _globals['_DEVICEAREADATAINFO']._serialized_end=801
  _globals['_DEVICENAVIGATIONPOINTDATAINFO']._serialized_start=803
  _globals['_DEVICENAVIGATIONPOINTDATAINFO']._serialized_end=921
  _globals['_CLEANPERFERENCEDATAINFO']._serialized_start=923
  _globals['_CLEANPERFERENCEDATAINFO']._serialized_end=1026
  _globals['_ROOMDATAINFO']._serialized_start=1029
  _globals['_ROOMDATAINFO']._serialized_end=1300
  _globals['_DEVICEROOMMATRIX']._serialized_start=1302
  _globals['_DEVICEROOMMATRIX']._serialized_end=1336
  _globals['_DEVICECHAINPOINTDATAINFO']._serialized_start=1338
  _globals['_DEVICECHAINPOINTDATAINFO']._serialized_end=1401
  _globals['_DEVICEROOMCHAINDATAINFO']._serialized_start=1403
  _globals['_DEVICEROOMCHAINDATAINFO']._serialized_end=1495
  _globals['_OBJECTDATAINFO']._serialized_start=1498
  _globals['_OBJECTDATAINFO']._serialized_end=1626
  _globals['_FURNITUREDATAINFO']._serialized_start=1628
  _globals['_FURNITUREDATAINFO']._serialized_end=1730
  _globals['_HOUSEINFO']._serialized_start=1732
  _globals['_HOUSEINFO']._serialized_end=1845
  _globals['_ROBOTMAP']._serialized_start=1848
  _globals['_ROBOTMAP']._serialized_end=2633
# @@protoc_insertion_point(module_scope)
